@@ -1,8 +1,14 @@
+import django
+
 from django import forms
 from django.conf import settings
 from django.core.mail.message import EmailMessage
 from django.template import loader
-from django.utils.translation import ugettext_lazy as _
+
+if django.get_version() >= '3.0.0':
+    from django.utils.translation import gettext_lazy as _
+else:
+    from django.utils.translation import ugettext_lazy as _
 
 
 class BaseEmailFormMixin(object):
@@ -13,10 +19,12 @@ class BaseEmailFormMixin(object):
     message_template_name = 'contact_form/email_template.txt'
 
     def get_message(self):
-        return loader.render_to_string(self.message_template_name, self.get_context())
+        return loader.render_to_string(self.message_template_name,
+                                       self.get_context())
 
     def get_subject(self):
-        subject = loader.render_to_string(self.subject_template_name, self.get_context())
+        subject = loader.render_to_string(self.subject_template_name,
+                                          self.get_context())
         return ''.join(subject.splitlines())
 
     def get_context(self):
@@ -67,7 +75,8 @@ class BaseEmailFormMixin(object):
 
     def send_email(self, request, fail_silently=False):
         self.request = request
-        return EmailMessage(**self.get_message_dict()).send(fail_silently=fail_silently)
+        return EmailMessage(**self.get_message_dict()).send(
+            fail_silently=fail_silently)
 
 
 class ContactForm(forms.Form, BaseEmailFormMixin):
