@@ -5,7 +5,7 @@ import mock
 
 from django import test
 from django.core import mail
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.template import loader, TemplateDoesNotExist
 from django import forms as django_forms
 
@@ -13,7 +13,6 @@ from contact_form import forms, views
 
 
 class AcceptanceTestsContactCompletedPage(test.TestCase):
-
     def test_receives_200_status_code_for_completed_page(self):
         response = self.client.get(reverse("contact_form:completed"))
         self.assertEqual(200, response.status_code)
@@ -50,13 +49,14 @@ class SampleCustomizedTestForm(forms.BaseEmailFormMixin, django_forms.Form):
 
 
 class BaseEmailFormMixinTests(test.TestCase):
-
     @mock.patch('django.template.loader.render_to_string')
-    def test_get_message_returns_rendered_message_template(self, render_to_string):
+    def test_get_message_returns_rendered_message_template(
+            self, render_to_string):
         context = {'message': 'an example message.'}
 
         class TestForm(forms.BaseEmailFormMixin):
             message_template_name = "my_template.html"
+
             def get_context(self):
                 return context
 
@@ -64,15 +64,18 @@ class BaseEmailFormMixinTests(test.TestCase):
 
         message = form.get_message()
         self.assertEqual(render_to_string.return_value, message)
-        render_to_string.assert_called_once_with(form.message_template_name, context)
+        render_to_string.assert_called_once_with(form.message_template_name,
+                                                 context)
 
     @mock.patch('django.template.loader.render_to_string')
-    def test_get_subject_returns_single_line_rendered_subject_template(self, render_to_string):
+    def test_get_subject_returns_single_line_rendered_subject_template(
+            self, render_to_string):
         render_to_string.return_value = 'This is \na \ntemplate.'
         context = {'message': 'an example message.'}
 
         class TestForm(forms.BaseEmailFormMixin):
             subject_template_name = "my_template.html"
+
             def get_context(self):
                 return context
 
@@ -80,16 +83,20 @@ class BaseEmailFormMixinTests(test.TestCase):
 
         subject = form.get_subject()
         self.assertEqual('This is a template.', subject)
-        render_to_string.assert_called_once_with(form.subject_template_name, context)
+        render_to_string.assert_called_once_with(form.subject_template_name,
+                                                 context)
 
-    def test_get_context_returns_cleaned_data_with_request_when_form_is_valid(self):
+    def test_get_context_returns_cleaned_data_with_request_when_form_is_valid(
+            self):
         request = test.RequestFactory().post("/")
+
         class TestForm(forms.BaseEmailFormMixin, forms.forms.Form):
             name = forms.forms.CharField()
 
         form = TestForm(data={'name': 'test'})
         form.request = request
-        self.assertEqual(dict(name='test', request=request), form.get_context())
+        self.assertEqual(
+            dict(name='test', request=request), form.get_context())
 
     def test_get_context_returns_value_error_when_form_is_invalid(self):
         class TestForm(forms.BaseEmailFormMixin, forms.forms.Form):
@@ -98,28 +105,27 @@ class BaseEmailFormMixinTests(test.TestCase):
         form = TestForm(data={})
         with self.assertRaises(ValueError) as ctx:
             form.get_context()
-        self.assertEqual("Cannot generate Context when form is invalid.", ctx.exception.message)
+        self.assertEqual("Cannot generate Context when form is invalid.",
+                         str(ctx.exception))
 
-    @mock.patch("contact_form.forms.EmailMessage", autospec=True, mocksignature=True)
-    @mock.patch("contact_form.forms.BaseEmailFormMixin.get_message_dict")
-    def test_sends_mail_with_message_dict(self, get_message_dict, email_class):
+    def test_sends_mail_with_message_dict(self):
         mock_request = test.RequestFactory().get('/')
-        get_message_dict.return_value = {"to": ["user@example.com"]}
 
-        form = forms.BaseEmailFormMixin()
-        result = form.send_email(mock_request)
+        form = SampleBasicTestForm(data={"field": "thing"})
+        form.send_email(mock_request)
 
-        email_class.assert_called_once_with(**get_message_dict.return_value)
-        email_class.return_value.send.assert_called_once_with(fail_silently=False)
-        self.assertEqual(email_class.return_value.send.return_value, result)
+        email = mail.outbox[0]
+        self.assertEqual(form.recipient_list, email.to)
+        self.assertEqual(form.from_email, email.from_email)
+        self.assertEqual(form.get_subject(), email.subject)
+        self.assertEqual(form.get_message(), email.body)
+        self.assertEqual([], email.cc)
+        self.assertEqual([], email.bcc)
 
-    @mock.patch("contact_form.forms.EmailMessage", autospec=True, mocksignature=True)
-    @mock.patch("contact_form.forms.BaseEmailFormMixin.get_message_dict")
-    def test_send_mail_sets_request_on_instance(self, get_message_dict, *mocks):
+    def test_send_mail_sets_request_on_instance(self):
         mock_request = test.RequestFactory().get('/')
-        get_message_dict.return_value = {"to": ["user@example.com"]}
 
-        form = forms.BaseEmailFormMixin()
+        form = SampleBasicTestForm(data={"field": "thing"})
         form.send_email(mock_request)
         self.assertEqual(mock_request, form.request)
 
@@ -169,9 +175,9 @@ class BaseEmailFormMixinTests(test.TestCase):
 
 
 class ContactFormTests(test.TestCase):
-
     def test_is_subclass_of_form_and_base_contact_form_mixin(self):
-        self.assertTrue(issubclass(forms.ContactForm, forms.BaseEmailFormMixin))
+        self.assertTrue(
+            issubclass(forms.ContactForm, forms.BaseEmailFormMixin))
         self.assertTrue(issubclass(forms.ContactForm, forms.forms.Form))
 
     def test_has_valid_subject_template(self):
@@ -188,7 +194,8 @@ class ContactFormTests(test.TestCase):
             loader.render_to_string(forms.ContactForm.message_template_name)
         except TemplateDoesNotExist:
             template_exists = 0
-        self.assertTrue(template_exists, "Email message template does not exist")
+        self.assertTrue(template_exists,
+                        "Email message template does not exist")
 
     def test_sends_mail_with_headers(self):
         class ReplyToForm(forms.ContactForm):
@@ -207,15 +214,17 @@ class ContactFormTests(test.TestCase):
 
 
 class ContactModelFormTests(test.TestCase):
-
     def test_is_subclass_of_model_form_and_base_contact_form_mixin(self):
-        self.assertTrue(issubclass(forms.ContactModelForm, forms.BaseEmailFormMixin))
-        self.assertTrue(issubclass(forms.ContactModelForm, forms.forms.ModelForm))
+        self.assertTrue(
+            issubclass(forms.ContactModelForm, forms.BaseEmailFormMixin))
+        self.assertTrue(
+            issubclass(forms.ContactModelForm, forms.forms.ModelForm))
 
     def test_has_valid_subject_template(self):
         template_exists = 1
         try:
-            loader.render_to_string(forms.ContactModelForm.subject_template_name)
+            loader.render_to_string(
+                forms.ContactModelForm.subject_template_name)
         except TemplateDoesNotExist:
             template_exists = 0
         self.assertTrue(template_exists, "Subject template does not exist")
@@ -223,7 +232,9 @@ class ContactModelFormTests(test.TestCase):
     def test_has_valid_message_template(self):
         template_exists = 1
         try:
-            loader.render_to_string(forms.ContactModelForm.message_template_name)
+            loader.render_to_string(
+                forms.ContactModelForm.message_template_name)
         except TemplateDoesNotExist:
             template_exists = 0
-        self.assertTrue(template_exists, "Email message template does not exist")
+        self.assertTrue(template_exists,
+                        "Email message template does not exist")
